@@ -149,6 +149,7 @@ defaults = {
             'toolbar': False,
             'new_episodes': 'show',  # ignore, show, queue, download
             'live_search_delay': 200,
+            'search_always_visible': False,
 
             'podcast_list': {
                 'all_episodes': True,
@@ -202,7 +203,6 @@ defaults = {
     'youtube': {
         'preferred_fmt_id': 18,  # default fmt_id (see fallbacks in youtube.py)
         'preferred_fmt_ids': [],  # for advanced uses (custom fallback sequence)
-        'api_key_v3': '',  # API key, register for one at https://developers.google.com/youtube/v3/
     },
 
     'vimeo': {
