@@ -21,6 +21,7 @@ import html
 import logging
 import os
 import sys
+import xml.etree.ElementTree as ET
 
 import dbus
 import dbus.service
@@ -46,6 +47,32 @@ _ = gpodder.gettext
 N_ = gpodder.ngettext
 
 
+def parse_app_menu_for_accels(filename):
+    """
+    grab (accelerator, action) bindings from menus.ui.
+    See #815 Ctrl-Q doesn't quit for justification.
+    Unfortunately it's not available from the Gio.MenuModel we get from the Gtk.Builder,
+    so we get it ourself.
+    """
+    res = []
+    menu_tree = ET.parse(filename)
+    assert menu_tree.getroot().tag == 'interface'
+    for menu in menu_tree.getroot():
+        assert menu.tag == 'menu'
+        if menu.attrib.get('id') == 'app-menu':
+            for itm in menu.iter('item'):
+                action = None
+                accel = None
+                for att in itm.findall('attribute'):
+                    if att.get('name') == 'action':
+                        action = att.text.strip()
+                    elif att.get('name') == 'accel':
+                        accel = att.text.strip()
+                if action and accel:
+                    res.append((accel, action))
+    return res
+
+
 class gPodderApplication(Gtk.Application):
 
     def __init__(self, options):
@@ -80,6 +107,10 @@ class gPodderApplication(Gtk.Application):
         action.connect('activate', self.on_check_for_updates_activate)
         self.add_action(action)
 
+        action = Gio.SimpleAction.new('menu', None)
+        action.connect('activate', self.on_menu)
+        self.add_action(action)
+
     def do_startup(self):
         Gtk.Application.do_startup(self)
 
@@ -88,10 +119,12 @@ class gPodderApplication(Gtk.Application):
         builder = Gtk.Builder()
         builder.set_translation_domain(gpodder.textdomain)
 
+        menu_filename = None
         for ui_folder in gpodder.ui_folders:
             filename = os.path.join(ui_folder, 'gtk/menus.ui')
             if os.path.exists(filename):
                 builder.add_from_file(filename)
+                menu_filename = filename
                 break
 
         menubar = builder.get_object('menubar')
@@ -102,7 +135,33 @@ class gPodderApplication(Gtk.Application):
         self.menu_view_columns = builder.get_object('menuViewColumns')
         self.set_menubar(menubar)
 
-        self.set_app_menu(builder.get_object('app-menu'))
+        # If $XDG_CURRENT_DESKTOP is set then it contains a colon-separated list of strings.
+        # https://specifications.freedesktop.org/desktop-entry-spec/desktop-entry-spec-latest.html
+        # See https://askubuntu.com/a/227669 for a list of values in different environments
+        xdg_current_desktops = os.environ.get('XDG_CURRENT_DESKTOP', '').split(':')
+        # See https://developer.gnome.org/gtk3/stable/gtk-running.html
+        # GTK_CSD=0 is used to disable client side decorations
+        csd_disabled = os.environ.get('GTK_CSD') == '0'
+
+        self.want_headerbar = ('GNOME' in xdg_current_desktops) and not gpodder.ui.osx and not csd_disabled
+
+        self.app_menu = builder.get_object('app-menu')
+        if self.want_headerbar:
+            # Use GtkHeaderBar for client-side decorations on recent GNOME 3 versions
+            self.header_bar_menu_button = Gtk.Button.new_from_icon_name('open-menu-symbolic', Gtk.IconSize.SMALL_TOOLBAR)
+            self.header_bar_menu_button.set_action_name('app.menu')
+
+            self.header_bar_refresh_button = Gtk.Button.new_from_icon_name('view-refresh-symbolic', Gtk.IconSize.SMALL_TOOLBAR)
+            self.header_bar_refresh_button.set_action_name('win.updateChannel')
+
+            self.menu_popover = Gtk.Popover.new_from_model(self.header_bar_menu_button, self.app_menu)
+            self.menu_popover.set_position(Gtk.PositionType.BOTTOM)
+
+            for (accel, action) in parse_app_menu_for_accels(menu_filename):
+                self.add_accelerator(accel, action, None)
+
+        else:
+            self.set_app_menu(self.app_menu)
 
         Gtk.Window.set_default_icon_name('gpodder')
 
@@ -137,6 +196,9 @@ class gPodderApplication(Gtk.Application):
 
         self.window.gPodder.present()
 
+    def on_menu(self, action, param):
+        self.menu_popover.popup()
+
     def on_about(self, action, param):
         dlg = Gtk.Dialog(_('About gPodder'), self.window.gPodder,
                 Gtk.DialogFlags.MODAL)
