@@ -21,9 +21,8 @@ Based on SimpleGladeApp.py Copyright (C) 2004 Sandino Flores Moreno
 # USA
 
 import os
-import sys
 import re
-
+import sys
 import tokenize
 
 from gi.repository import Gtk
@@ -55,7 +54,7 @@ class GtkBuilderWidget(object):
             for (key, value) in list(self._builder_expose.items()):
                 self.builder.expose_object(key, value)
 
-        #print >>sys.stderr, 'Creating new from file', self.__class__.__name__
+        # print >>sys.stderr, 'Creating new from file', self.__class__.__name__
 
         ui_file = '%s.ui' % self.__class__.__name__.lower()
 
@@ -88,7 +87,9 @@ class GtkBuilderWidget(object):
 
             widget_api_name = '_'.join(re.findall(tokenize.Name, widget_name))
             if hasattr(self, widget_api_name):
-                raise AttributeError("instance %s already has an attribute %s" % (self,widget_api_name))
+                raise AttributeError(
+                    "instance %s already has an attribute %s" % (
+                        self, widget_api_name))
             else:
                 setattr(self, widget_api_name, widget)
 
@@ -149,4 +150,3 @@ class GtkBuilderWidget(object):
         after a program is finished by pressing Control-C.
         """
         pass
-
