@@ -112,37 +112,24 @@ class YouTubeVideoFormatListModel(Gtk.ListStore):
     def __init__(self, config):
         Gtk.ListStore.__init__(self, str, int)
         self._config = config
-        self.custom_fmt_ids = self._config.youtube.preferred_fmt_ids
 
         if self._config.youtube.preferred_fmt_ids:
             caption = _('Custom (%(format_ids)s)') % {
-                'format_ids': ', '.join(str(x) for x in self.custom_fmt_ids),
+                'format_ids': ', '.join(str(x) for x in self._config.youtube.preferred_fmt_ids),
             }
-            self.append((caption, -1))
+            self.append((caption, 0))
 
         for id, (fmt_id, path, description) in youtube.formats:
             self.append((description, id))
 
     def get_index(self):
-        if self._config.youtube.preferred_fmt_ids:
-            return 0
-
         for index, row in enumerate(self):
             if self._config.youtube.preferred_fmt_id == row[self.C_ID]:
                 return index
         return 0
 
     def set_index(self, index):
-        value = self[index][self.C_ID]
-        if value > 0:
-            self._config.youtube.preferred_fmt_id = value
-            # If we set a value, we need to unset the custom one, so that
-            # the single value (preferred_fmt_id) gets used instead
-            self._config.youtube.preferred_fmt_ids = []
-        else:
-            # If the user selects the -1 value, it's our custom one, and
-            # we need to restore the value for preferred_fmt_ids
-            self._config.youtube.preferred_fmt_ids = self.custom_fmt_ids
+        self._config.youtube.preferred_fmt_id = self[index][self.C_ID]
 
 
 class VimeoVideoFormatListModel(Gtk.ListStore):
@@ -280,7 +267,6 @@ class gPodderPreferences(BuilderWidget):
         self.entry_username.set_text(self._config.mygpo.username)
         self.entry_password.set_text(self._config.mygpo.password)
         self.entry_caption.set_text(self._config.mygpo.device.caption)
-        self.entry_youtube_api_key.set_text(self._config.youtube.api_key_v3)
 
         # Disable mygpo sync while the dialog is open
         self._config.mygpo.enabled = False
@@ -290,6 +276,13 @@ class gPodderPreferences(BuilderWidget):
 
         self._config.connect_gtk_window(self.main_window, 'preferences', True)
 
+        gpodder.user_extensions.on_ui_object_available('preferences-gtk', self)
+
+        result = gpodder.user_extensions.on_preferences()
+        if result:
+            for label, callback in result:
+                self.notebook.append_page(callback(), Gtk.Label(label))
+
     def _extensions_select_function(self, selection, model, path, path_currently_selected):
         return model.get_value(model.get_iter(path), self.C_SHOW_TOGGLE)
 
@@ -543,12 +536,6 @@ class gPodderPreferences(BuilderWidget):
         # Only update indirectly (see on_dialog_destroy)
         self._enable_mygpo = widget.get_active()
 
-    def on_youtube_api_key_changed(self, widget):
-        self._config.youtube.api_key_v3 = widget.get_text()
-
-    def on_button_youtube_api_key_clicked(self, widget):
-        util.open_website('http://wiki.gpodder.org/wiki/Youtube')
-
     def on_server_changed(self, widget):
         self._config.mygpo.server = widget.get_text()
 
